@@ -24,7 +24,6 @@ SOFTWARE.
 from bale.version import BALE_API_BASE_URL, BALE_API_FILE_URL
 import asyncio
 import aiohttp
-from typing import Any
 from ..error import (NetworkError, TimeOut, NotFound, Forbidden, APIError, BaleError, HTTPClientError, RateLimited, HTTPException)
 from .parser import ResponseParser
 from .utils import ResponseStatusCode
@@ -40,7 +39,7 @@ class RateLimit:
 		"_has_rate_limit"
 	)
 	def __init__(self, loop):
-		self._has_rate_limit = None
+		self._has_rate_limit = False
 		self._requests = deque()
 		self._loop = loop
 
@@ -72,6 +71,7 @@ class RateLimit:
 				future.cancel()
 				if not self._has_rate_limit:
 					self._next()
+				raise
 
 	async def __aenter__(self):
 		await self.new_request()
@@ -80,15 +80,14 @@ class RateLimit:
 	async def __aexit__(self, exc_type, exc_val, exc_tb):
 		if len(self._requests) > 0:
 			self._next()
+		else:
+			self._has_rate_limit = False
 
 	def __bool__(self):
 		return self._has_rate_limit
 
 class Route:
 	"""Route Class for http"""
-	BASE = BALE_API_BASE_URL
-	BASE_FILE = BALE_API_FILE_URL
-
 	__slots__ = (
 		"method",
 		"path",
@@ -102,12 +101,12 @@ class Route:
 		self.method = method
 		self.path = path
 		self.token = token
-		self._base = self.BASE
+		self._base = BALE_API_BASE_URL
 
 	@property
 	def url(self):
-		"""Export url"""
-		return self.BASE + "bot" + self.token + "/" + self.path
+		"""finally url"""
+		return self._base + "bot" + self.token + "/" + self.path
 
 	def set_base(self, _value):
 		"""Set base url for route"""
@@ -120,14 +119,16 @@ class HTTPClient:
 		"_loop",
 		"token",
 		"__session",
-		"rate_limit"
+		"rate_limit",
+		"base_url"
 	)
 
-	def __init__(self, loop, token=None):
+	def __init__(self, loop, token=None, base_url = None):
 		self.__session = None
 		self._loop: asyncio.AbstractEventLoop = loop
 		self.token = token
 		self.rate_limit = RateLimit(self.loop)
+		self.base_url: str = base_url
 
 	def is_closed(self):
 		return self.__session is None
@@ -144,11 +145,11 @@ class HTTPClient:
 	def reload_session(self):
 		"""Reset Session"""
 		if self.__session and self.__session.closed:
-			self.__session = aiohttp.ClientSession(loop=self.loop, connector=aiohttp.TCPConnector(limit=5, keepalive_timeout=20.0))
+			self.__session = aiohttp.ClientSession(loop=self.loop, connector=aiohttp.TCPConnector(keepalive_timeout=20.0))
 
 	async def start(self):
 		"""Start Http client"""
-		self.__session = aiohttp.ClientSession(loop=self.loop, connector=aiohttp.TCPConnector(limit=5, keepalive_timeout=20.0))
+		self.__session = aiohttp.ClientSession(loop=self.loop, connector=aiohttp.TCPConnector(keepalive_timeout=20.0))
 
 	async def close(self):
 		"""Close Session connection"""
@@ -157,6 +158,8 @@ class HTTPClient:
 			self.__session = None
 
 	async def request(self, route: Route, **kwargs):
+		if self.base_url:
+			route.set_base(self.base_url)
 		url = route.url
 		method = route.method
 		async with self.rate_limit:
@@ -165,7 +168,9 @@ class HTTPClient:
 					async with self.__session.request(method=method, url=url, **kwargs) as response:
 						response: aiohttp.ClientResponse = response
 						parsed_response = await ResponseParser.from_response(response)
-						if response.status == ResponseStatusCode.NOT_FOUND:
+						if response.status == ResponseStatusCode.OK:
+							return parsed_response
+						elif response.status == ResponseStatusCode.NOT_FOUND:
 							raise NotFound(parsed_response.description)
 						elif not parsed_response.ok or response.status in (ResponseStatusCode.NOT_INCORRECT, ResponseStatusCode.RATE_LIMIT):
 							if parsed_response.description == HTTPClientError.USER_OR_CHAT_NOT_FOUND:
@@ -186,13 +191,11 @@ class HTTPClient:
 							raise APIError(
 									str(parsed_response.error_code), parsed_response.description
 								)
-						elif response.status == ResponseStatusCode.OK:
-							return parsed_response
-				except aiohttp.client_exceptions.ClientConnectorError as error:
+				except aiohttp.ClientConnectorError as error:
 					raise NetworkError(str(error))
-				except aiohttp.client_exceptions.ServerTimeoutError:
+				except aiohttp.ServerTimeoutError:
 					raise TimeOut()
-				except aiohttp.client_exceptions.ClientOSError as error:
+				except aiohttp.ClientOSError as error:
 					raise BaleError(str(error))
 				except Exception as error:
 					raise HTTPException(error)
@@ -248,6 +251,33 @@ class HTTPClient:
 
 		return self.request(Route("POST", "SendPhoto", self.token), data=payload)
 
+	def send_audio(self, chat_id, audio, *, caption=None, duration=None, title=None, reply_to_message_id=None):
+		payload = {
+			"chat_id": chat_id,
+			"audio": audio
+		}
+		if caption:
+			payload["caption"] = caption
+		if duration:
+			payload["duration"] = duration
+		if title:
+			payload["title"] = title
+		if reply_to_message_id:
+			payload["reply_to_message_id"] = reply_to_message_id
+
+		return self.request(Route("POST", "SendAudio", self.token), data=payload)
+
+	def send_contact(self, chat_id, phone_number, first_name, *, last_name):
+		payload = {
+			"chat_id": chat_id,
+			"phone_number": phone_number,
+			"first_name": first_name
+		}
+		if last_name:
+			payload["last_name"] = last_name
+
+		return self.request(Route("POST", "SendContact", self.token), data=payload)
+
 	def send_invoice(self, chat_id, title, description, provider_token, prices, photo_url=None, need_name=False, need_phone_number=False, need_email=False, need_shipping_address=False, is_flexible=True):
 		payload = {"chat_id": chat_id, "title": title, "description": description, "provider_token": provider_token, "prices": prices}
 		if photo_url:
@@ -260,6 +290,11 @@ class HTTPClient:
 
 		return self.request(Route("POST", "sendInvoice", self.token), json=payload)
 
+	def send_location(self, chat_id, latitude, longitude):
+		payload = { "chat_id": chat_id, "latitude": latitude, "longitude": longitude}
+
+		return self.request(Route("POST", "sendLocation", self.token), json=payload)
+
 	def edit_message(self, chat_id, message_id, text, *, components=None):
 		payload = {
 			"chat_id": chat_id,
